pub enum LatestEventValue {
None,
Remote(RemoteLatestEventValue),
RemoteInvite {
event_id: Option<OwnedEventId>,
timestamp: MilliSecondsSinceUnixEpoch,
inviter: Option<OwnedUserId>,
},
LocalIsSending(LocalLatestEventValue),
LocalHasBeenSent {
event_id: OwnedEventId,
value: LocalLatestEventValue,
},
LocalCannotBeSent(LocalLatestEventValue),
}Expand description
A latest event value!
Variants
None
No value has been computed yet, or no candidate value was found.
Remote(RemoteLatestEventValue)
The latest event represents a remote event.
RemoteInvite
The latest event represents an invite, i.e. the current user has been invited to join a room.
Fields
event_id: Option<OwnedEventId>The ID of the invite event.
timestamp: MilliSecondsSinceUnixEpochThe timestamp of the invite event.
inviter: Option<OwnedUserId>The user ID of the inviter.
LocalIsSending(LocalLatestEventValue)
The latest event represents a local event that is sending.
LocalHasBeenSent
The latest event represents a local event that has been sent
successfully. It should come quickly as a Self::Remote.
Fields
event_id: OwnedEventIdID of the sent event.
value: LocalLatestEventValueValue, as for other Self::Local* variants.
LocalCannotBeSent(LocalLatestEventValue)
The latest event represents a local event that cannot be sent, either because a previous local event, or this local event cannot be sent.
Implementations
Sourceimpl LatestEventValue
impl LatestEventValue
Sourcepub fn timestamp(&self) -> Option<MilliSecondsSinceUnixEpoch>
pub fn timestamp(&self) -> Option<MilliSecondsSinceUnixEpoch>
Get the timestamp of the LatestEventValue.
- If it’s
None, it returnsNone. - If it’s
Remote, it returns theTimelineEvent::timestamp. - If it’s
RemoteInvite, it returns theSyncOrStrippedState::timestamp. - If it’s
LocalIsSending,LocalHasBeenSentorLocalCannotBeSent, it returns theLocalLatestEventValue::timestampvalue.
Sourcepub fn is_local(&self) -> bool
pub fn is_local(&self) -> bool
Check whether the LatestEventValue represents a local value or not,
i.e. it is LocalIsSending or LocalCannotBeSent.
Sourcepub fn is_unsent(&self) -> bool
pub fn is_unsent(&self) -> bool
Check whether the LatestEventValue represents an unsent event, i.e.
is LocalIsSending nor LocalCannotBeSent.
Sourcepub fn is_none(&self) -> bool
pub fn is_none(&self) -> bool
Check whether the LatestEventValue is not set, i.e. None.
Sourcepub fn event_id(&self) -> Option<OwnedEventId>
pub fn event_id(&self) -> Option<OwnedEventId>
Get the event ID (if it exists) of the event representing the
LatestEventValue.